pub struct DecodedException<'a> {
pub bits: ExceptionBits,
pub lowercase: Option<char>,
pub casefold: Option<char>,
pub uppercase: Option<char>,
pub titlecase: Option<char>,
pub simple_case_delta: Option<u32>,
pub closure: Option<Cow<'a, str>>,
pub full: Option<[Cow<'a, str>; 4]>,
}Expand description
A decoded Exception type, with all of the data parsed out into
separate fields.
🚧 This code is considered unstable; it may change at any time, in breaking or non-breaking ways,
including in SemVer minor releases. While the serde representation of data structs is guaranteed
to be stable, their Rust representation might not be. Use with caution.
Fields
bits: ExceptionBitsThe various bit-based data associated with this exception
lowercase: Option<char>Lowercase mapping
casefold: Option<char>Case folding
uppercase: Option<char>Uppercase mapping
titlecase: Option<char>Titlecase mapping
simple_case_delta: Option<u32>The simple casefold delta. Its sign is stored in bits.negative_delta
closure: Option<Cow<'a, str>>Closure mappings
full: Option<[Cow<'a, str>; 4]>The four full-mappings strings, indexed by MappingKind u8 value
Implementations