#[repr(C, packed(1))]pub struct ExceptionULE {
pub bits: <ExceptionBits as AsULE>::ULE,
pub slot_presence: <SlotPresence as AsULE>::ULE,
pub data: str,
}Fields
bits: <ExceptionBits as AsULE>::ULEslot_presence: <SlotPresence as AsULE>::ULEdata: strImplementations
Sourceimpl ExceptionULE
impl ExceptionULE
fn empty_exception() -> &'static Self
pub(crate) fn has_slot(&self, slot: ExceptionSlot) -> bool
Sourcepub(crate) fn get_char_slot(&self, slot: ExceptionSlot) -> Option<char>
pub(crate) fn get_char_slot(&self, slot: ExceptionSlot) -> Option<char>
Obtain a char slot, if occupied. If slot represents a string slot,
will return None
Sourcefn get_simple_case_delta(&self) -> Option<u32>
fn get_simple_case_delta(&self) -> Option<u32>
Get the simple_case delta (i.e. the delta slot), given the character
this data belongs to.
Normalizes the delta from char-format to u32 format
Does not handle the sign of the delta; see self.bits.negative_delta
Sourcepub(crate) fn get_simple_case_slot_for(&self, ch: char) -> Option<char>
pub(crate) fn get_simple_case_slot_for(&self, ch: char) -> Option<char>
Get the simple_case value (i.e. the delta slot), given the character
this data belongs to.
The data is stored as a delta so the character must be provided.
The data cannot be stored directly as a character because the trie is more compact with adjacent characters sharing deltas.
Sourcefn get_stringy_data(&self) -> Option<&str>
fn get_stringy_data(&self) -> Option<&str>
Returns all the data in the closure/full slots, including length metadata
Sourcefn get_stringy_slot(&self, slot: ExceptionSlot) -> Option<&str>
fn get_stringy_slot(&self, slot: ExceptionSlot) -> Option<&str>
Returns a single stringy slot, either ExceptionSlot::Closure or ExceptionSlot::FullMappings.
Sourcepub(crate) fn get_closure_slot(&self) -> Option<&str>
pub(crate) fn get_closure_slot(&self) -> Option<&str>
Get the data behind the closure slot
Sourcefn get_fullmappings_slot_data(&self) -> Option<&str>
fn get_fullmappings_slot_data(&self) -> Option<&str>
Get all the slot data for the FullMappings slot
This needs to be further segmented into four based on length metadata
Sourcepub(crate) fn get_fullmappings_slot_for_kind(
&self,
kind: MappingKind,
) -> Option<&str>
pub(crate) fn get_fullmappings_slot_for_kind( &self, kind: MappingKind, ) -> Option<&str>
Get a specific FullMappings slot value
fn get_all_fullmapping_slots(&self) -> Option<[Cow<'_, str>; 4]>
pub(crate) fn slot_char_for_kind(&self, kind: MappingKind) -> Option<char>
pub(crate) fn add_full_and_closure_mappings<S: ClosureSink>(&self, set: &mut S)
Sourcepub fn decode(&self) -> DecodedException<'_>
pub fn decode(&self) -> DecodedException<'_>
Extract all the data out into a structured form
Useful for serialization and debugging